@@ -3,13 +3,15 @@ import glob
 import os
 import re
 
-from exceptions import DuplicateJSONFile, InvalidClientInput
+from exceptions import (
+    DuplicateJSONFile, InvalidParameter, ExistingEnvironmentVariable)
 
 
 class ConfigurationPanda(object):
     """
-    So, what I want to do is increase the flexibility of the object class
-    so that usage => ConfigurationPanda[x] == ConfigurationPanda.x
+    Provides access to the contents of JSON configuration files using
+    object or dictionary style syntax.
+
     """
 
     def __init__(self, config_files_location_env_vars=['CONFIGURATION_PANDA']):
@@ -24,13 +26,9 @@ class ConfigurationPanda(object):
                 configuration files.  Defaults to a list containing
                 the single entry 'CONFIGURATION_PANDA'.
 
-        Raises:
-            DuplicateJSONFile: When an attempt is
-                made to load two JSON files with the same name.
-
         """
         if not isinstance(config_files_location_env_vars, list):
-            raise InvalidClientInput(
+            raise InvalidParameter(
                 'config_files_location_env_vars must by a list.')
 
         configuration_files = (
@@ -43,7 +41,8 @@ class ConfigurationPanda(object):
             self._check_for_existing_attribute(attribute_name)
             self._load_data_onto_attribute(attribute_name, configuration_file)
 
-        self._load_environment_variables()
+        if hasattr(self, 'environment_variables'):
+            self._load_environment_variables()
 
     def __getitem__(self, item):
         """
@@ -52,17 +51,24 @@ class ConfigurationPanda(object):
         """
         return self.__dict__[item]
 
-    def _configuration_files(self, config_files_location_env_vars):
+    def _configuration_files(self, config_files_locations):
+        """
+        Raises:
+            DuplicateJSONFile: When an attempt is
+                made to load two JSON files with the same name.
+
+        """
         configuration_files = list()
-        for env_var in config_files_location_env_vars:
+        for config_files_location in config_files_locations:
             try:
                 configuration_files.extend(glob.glob(
-                    os.environ[env_var] + '/*.json'))
+                    os.environ[config_files_location] + '/*.json'))
             except KeyError:
-                raise InvalidClientInput('The environment variable specified '
-                                         'by the client ({}) for use by '
-                                         'the constructor does not exist'
-                                         'on the system.'.format(env_var))
+                raise InvalidParameter('The environment variable specified '
+                                       'by the client ({}) for use by '
+                                       'the constructor does not exist '
+                                       'on the system.'.format(
+                                           config_files_location))
         return configuration_files
 
     def _check_for_existing_attribute(self, attribute_name):
@@ -82,7 +88,19 @@ class ConfigurationPanda(object):
                     "syntax errors.".format(configuration_file))
 
     def _load_environment_variables(self):
-        if hasattr(self, 'environment_variables'):
-            for env_var in self.environment_variables:
-                os.environ[env_var] = self.environment_variables[env_var]
+        """
+        Set each element of self.environment_variables as an
+        environment variable.
 
+        Raises:
+            ExistingEnvironmentVariable: If setting a environment variable
+              would overwrite an existing value.
+
+        """
+        for env_var in self.environment_variables:
+            if env_var in os.environ:
+                raise ExistingEnvironmentVariable(
+                    'An attempt was made to set the environment variable '
+                    '{}, but this variable already exists.'.format(env_var)
+                )
+            os.environ[env_var] = self.environment_variables[env_var]
